@@ -345,8 +345,8 @@ def optimize_neighborhood_imputation_prior_strength(
     replicate_indices: List[int], 
     spatial_bandwidth: float, 
     deviation_weights: List[float], 
-    KL_score_weights: List[float]) -> Tuple[List[float], List[float]]:
-
+    KL_score_weights: List[float],
+    neighborhood_optimization_guide_sample_size: int = 50) -> Tuple[List[float], List[float]]:
 
     def retrieve_objective_of_guide_set(rep_i, guide_set: List[Guide], params):
         spatial_imputation_prior_strength_test, spatial_imputation_likelihood_strength_test = params
@@ -354,7 +354,10 @@ def optimize_neighborhood_imputation_prior_strength(
             return 0, 0
 
         KL_guide_imputation_score_total: float = 0
-        sampled_guide_set = random.sample(guide_set, 50)
+
+        neighborhood_optimization_guide_sample_size_i = len(guide_set) if neighborhood_optimization_guide_sample_size > len(guide_set) else neighborhood_optimization_guide_sample_size
+
+        sampled_guide_set = random.sample(guide_set, neighborhood_optimization_guide_sample_size_i)
         for each_guide in sampled_guide_set:
             # Ensure that the guide contains a position
 
@@ -1144,8 +1147,8 @@ if __name__ == "__main__":
         monte_carlo_trials = 1000,
         enable_spatial_prior =  True,
         spatial_bandwidth = 7,
-        neighborhood_imputation_model_weights= np.asarray([[0.00072893, 0.00047752, 0.00259672],[0.62589106, 0.21313737, 0.92475451]]),
-        singleton_imputation_model_weights = np.asarray([0.00142129, 0.00128178, 0.00137408]),
+        neighborhood_imputation_model_weights= None,
+        singleton_imputation_model_weights = None,
         baseline_proportion = 0.5, # TODO: Perform validation between (0,1), also accept None value for perfrming no normalization (or have that be another argument)
         deviation_weights = [1,1,1],
         KL_score_weights = None,
